==> webkit2gtk_2.50.0.orig.tar.xz: webkitgtk-2.50.0/Source/WebCore/Modules/webcodecs/OpusEncoderConfig.h <==
/*
 * Copyright (C) 2023 Igalia S.L
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * aint with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#pragma once

#if ENABLE(WEB_CODECS)

#include <algorithm>
#include <optional>
#include <wtf/Vector.h>

namespace WebCore {

enum class OpusBitstreamFormat : uint8_t {
    Opus,
    Ogg
};

// https://www.w3.org/TR/webcodecs-opus-codec-registration/#opus-encoder-config
struct OpusEncoderConfig {
    bool isValid()
    {
        float frameDurationMs = frameDuration / 1000.0;
        if (!std::ranges::any_of(std::initializer_list<float> { 2.5, 5, 10, 20, 40, 60, 120 }, [frameDurationMs](auto value) {
            return WTF::areEssentiallyEqual(value, frameDurationMs);
        })) {
            return false;
        }
        if (complexity > 10)
            return false;

        if (packetlossperc > 100)
            return false;

        return true;
    }

    using BitstreamFormat = OpusBitstreamFormat;
    OpusBitstreamFormat format { OpusBitstreamFormat::Opus };
    uint64_t frameDuration { 20000 };
    size_t complexity { 9 };
    size_t packetlossperc { 0 };
    bool useinbandfec { false };
    bool usedtx { false };
};

}

#endif // ENABLE(WEB_CODECS)

==> webkit2gtk_2.51.3.orig.tar.xz: webkitgtk-2.51.3/Source/WebCore/Modules/webcodecs/OpusEncoderConfig.h <==
/*
 * Copyright (C) 2023 Igalia S.L
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * aint with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#pragma once

#if ENABLE(WEB_CODECS)

#include <algorithm>
#include <optional>
#include <wtf/Vector.h>

namespace WebCore {

enum class OpusBitstreamFormat : uint8_t {
    Opus,
    Ogg
};

// https://www.w3.org/TR/webcodecs-opus-codec-registration/#opus-encoder-config
struct OpusEncoderConfig {
    bool isValid()
    {
        float frameDurationMs = frameDuration / 1000.0;
        if (std::ranges::none_of(std::initializer_list<float> { 2.5, 5, 10, 20, 40, 60, 120 }, [frameDurationMs](auto value) {
            return WTF::areEssentiallyEqual(value, frameDurationMs);
        })) {
            return false;
        }
        if (complexity > 10)
            return false;

        if (packetlossperc > 100)
            return false;

        return true;
    }

    using BitstreamFormat = OpusBitstreamFormat;
    OpusBitstreamFormat format { OpusBitstreamFormat::Opus };
    uint64_t frameDuration { 20000 };
    size_t complexity { 9 };
    size_t packetlossperc { 0 };
    bool useinbandfec { false };
    bool usedtx { false };
};

}

#endif // ENABLE(WEB_CODECS)
